@@ -22,28 +22,25 @@ build_time_vars = {'ABIFLAGS': '',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'armv4--netbsdelf-eabi',
+ 'BUILD_GNU_TYPE': 'armv7--netbsdelf-eabihf',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include -I/usr/include/readline '
-           '-I/usr/pkg/include -O2 -I/usr/include -I/usr/include/readline '
-           '-I/usr/pkg/include -O2 -I/usr/include -I/usr/include/readline '
+ 'CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include -I/usr/pkg/include -O2 '
+           '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
            '-I/usr/pkg/include',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -I/usr/include -I/usr/include/readline '
-                     '-I/usr/pkg/include',
+ 'CONFIGURE_CFLAGS': '-O2 -I/usr/include -I/usr/pkg/include',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
- 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/include/readline '
-                       '-I/usr/pkg/include',
+ 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include',
  'CONFIGURE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                       '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
                       '-Wl,-R/usr/X11R7/lib',
@@ -51,31 +48,29 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-expat' "
                 "'--with-system-ffi' '--without-ensurepip' "
-                "'--without-pymalloc' '--with-readline=editline' "
-                "'--prefix=/usr/pkg' '--build=armv4--netbsdelf-eabi' "
-                "'--host=armv4--netbsdelf-eabi' '--mandir=/usr/pkg/man' "
+                "'--without-pymalloc' '--with-readline=readline' "
+                "'--prefix=/usr/pkg' '--build=armv7--netbsdelf-eabihf' "
+                "'--host=armv7--netbsdelf-eabihf' '--mandir=/usr/pkg/man' "
                 "'--enable-option-checking=yes' "
-                "'build_alias=armv4--netbsdelf-eabi' "
-                "'host_alias=armv4--netbsdelf-eabi' "
-                "'PKG_CONFIG=/tmp/pkgbuild/lang/python311/work.earmv4/.tools/bin/pkg-config' "
+                "'build_alias=armv7--netbsdelf-eabihf' "
+                "'host_alias=armv7--netbsdelf-eabihf' "
+                "'PKG_CONFIG=/mnt/earmv7hf/pkgsrc/lang/python311/work.earmv7hf/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python311/work.earmv4/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python311/work.earmv4/.buildlink/share/pkgconfig' "
-                "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/include/readline "
-                "-I/usr/pkg/include' 'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib "
-                '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
-                "-Wl,-R/usr/X11R7/lib' 'LIBS=' 'CPPFLAGS=-I/usr/include "
-                "-I/usr/include/readline -I/usr/pkg/include'",
+                "'PKG_CONFIG_LIBDIR=/mnt/earmv7hf/pkgsrc/lang/python311/work.earmv7hf/.buildlink/lib/pkgconfig:/mnt/earmv7hf/pkgsrc/lang/python311/work.earmv7hf/.buildlink/share/pkgconfig' "
+                "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/pkg/include' "
+                "'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib "
+                "-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' "
+                "'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python311/work.earmv4/Python-3.11.10/coverage.info',
+ 'COVERAGE_INFO': '/mnt/earmv7hf/pkgsrc/lang/python311/work.earmv7hf/Python-3.11.12/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python311/work.earmv4/Python-3.11.10/lcov-report',
+ 'COVERAGE_REPORT': '/mnt/earmv7hf/pkgsrc/lang/python311/work.earmv7hf/Python-3.11.12/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
- 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/include/readline '
-             '-I/usr/pkg/include -I/usr/include -I/usr/include/readline '
+ 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
              '-I/usr/pkg/include',
  'CXX': 'c++ -pthread',
  'DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1',
@@ -368,7 +363,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MADVISE': 1,
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
- 'HAVE_MEMFD_CREATE': 0,
+ 'HAVE_MEMFD_CREATE': 1,
  'HAVE_MEMORY_H': 1,
  'HAVE_MEMRCHR': 1,
  'HAVE_MKDIRAT': 1,
@@ -429,12 +424,12 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_RECVFROM': 1,
  'HAVE_RENAMEAT': 1,
  'HAVE_RL_APPEND_HISTORY': 1,
- 'HAVE_RL_CATCH_SIGNAL': 0,
- 'HAVE_RL_COMPDISP_FUNC_T': 0,
- 'HAVE_RL_COMPLETION_APPEND_CHARACTER': 0,
+ 'HAVE_RL_CATCH_SIGNAL': 1,
+ 'HAVE_RL_COMPDISP_FUNC_T': 1,
+ 'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
  'HAVE_RL_COMPLETION_MATCHES': 1,
- 'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 0,
+ 'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
  'HAVE_RL_RESIZE_TERMINAL': 1,
  'HAVE_RPC_RPC_H': 1,
@@ -611,16 +606,16 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_H': 0,
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
- 'HOST_GNU_TYPE': 'armv4--netbsdelf-eabi',
+ 'HOST_GNU_TYPE': 'armv7--netbsdelf-eabihf',
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
                    '/usr/pkg/include/python3.11 /usr/pkg/include/python3.11',
  'INCLUDEDIR': '/usr/pkg/include',
  'INCLUDEPY': '/usr/pkg/include/python3.11',
- 'INSTALL': '/usr/bin/install -c -o pbulk -g users',
- 'INSTALL_DATA': '/usr/bin/install -c -o pbulk -g users -m 644',
- 'INSTALL_PROGRAM': '/usr/bin/install -c -s -o pbulk -g users -m 755',
- 'INSTALL_SCRIPT': '/usr/bin/install -c -o pbulk -g users -m 755',
- 'INSTALL_SHARED': '/usr/bin/install -c -o pbulk -g users -m 755',
+ 'INSTALL': '/usr/bin/install -c -o root -g wheel',
+ 'INSTALL_DATA': '/usr/bin/install -c -o root -g wheel -m 644',
+ 'INSTALL_PROGRAM': '/usr/bin/install -c -s -o root -g wheel -m 755',
+ 'INSTALL_SCRIPT': '/usr/bin/install -c -o root -g wheel -m 755',
+ 'INSTALL_SHARED': '/usr/bin/install -c -o root -g wheel -m 755',
  'INSTSONAME': 'libpython3.11.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
@@ -642,16 +637,13 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDIR': '/usr/pkg/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include '
-                    '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                    '-O2 -I/usr/include -I/usr/include/readline '
-                    '-I/usr/pkg/include -std=gnu11 -Wextra '
+                    '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                    '-O2 -I/usr/include -I/usr/pkg/include -std=gnu11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                    '-fPIC -fPIC',
+                    '-I/usr/include -I/usr/pkg/include -I/usr/include '
+                    '-I/usr/pkg/include -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
  'LIBFFI_INCLUDEDIR': '/usr/pkg/include',
@@ -659,16 +651,13 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1 '
                     '-Wsign-compare -DNDEBUG -O2 -I/usr/include '
-                    '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                    '-O2 -I/usr/include -I/usr/include/readline '
-                    '-I/usr/pkg/include -std=gnu11 -Wextra '
+                    '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                    '-O2 -I/usr/include -I/usr/pkg/include -std=gnu11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                    '-fPIC -fPIC',
+                    '-I/usr/include -I/usr/pkg/include -I/usr/include '
+                    '-I/usr/pkg/include -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
@@ -917,8 +906,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '-L/usr/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
- 'OPT': '-DNDEBUG -O2 -I/usr/include -I/usr/include/readline '
-        '-I/usr/pkg/include',
+ 'OPT': '-DNDEBUG -O2 -I/usr/include -I/usr/pkg/include',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -955,46 +943,39 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include '
-                             '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                             '-I/usr/include -I/usr/include/readline '
                              '-I/usr/pkg/include -O2 -I/usr/include '
-                             '-I/usr/include/readline -I/usr/pkg/include '
-                             '-std=gnu11 -Wextra -Wno-unused-parameter '
+                             '-I/usr/pkg/include -O2 -I/usr/include '
+                             '-I/usr/pkg/include -std=gnu11 -Wextra '
+                             '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
-                             '-I./Include -I/usr/include '
-                             '-I/usr/include/readline -I/usr/pkg/include '
-                             '-I/usr/include -I/usr/include/readline '
-                             '-I/usr/pkg/include -fPIC -DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include '
-              '-I/usr/include/readline -I/usr/pkg/include -O2 -I/usr/include '
-              '-I/usr/include/readline -I/usr/pkg/include -O2 -I/usr/include '
-              '-I/usr/include/readline -I/usr/pkg/include',
+                             '-I./Include -I/usr/include -I/usr/pkg/include '
+                             '-I/usr/include -I/usr/pkg/include -fPIC '
+                             '-DPy_BUILD_CORE_BUILTIN',
+ 'PY_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include -I/usr/pkg/include '
+              '-O2 -I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+              '-I/usr/pkg/include',
  'PY_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                      '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include '
-                   '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                   '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                   '-O2 -I/usr/include -I/usr/include/readline '
-                   '-I/usr/pkg/include -std=gnu11 -Wextra '
+                   '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                   '-O2 -I/usr/include -I/usr/pkg/include -std=gnu11 -Wextra '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                   '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                   '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                   '-fPIC -DPy_BUILD_CORE',
+                   '-I/usr/include -I/usr/pkg/include -I/usr/include '
+                   '-I/usr/pkg/include -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
                     '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
- 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/include/readline '
-                '-I/usr/pkg/include -I/usr/include -I/usr/include/readline '
-                '-I/usr/pkg/include',
+ 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
+                '-I/usr/include -I/usr/pkg/include',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
@@ -1011,17 +992,15 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include '
-                        '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                        '-I/usr/include -I/usr/include/readline '
                         '-I/usr/pkg/include -O2 -I/usr/include '
-                        '-I/usr/include/readline -I/usr/pkg/include -std=gnu11 '
-                        '-Wextra -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers -Wstrict-prototypes '
+                        '-I/usr/pkg/include -O2 -I/usr/include '
+                        '-I/usr/pkg/include -std=gnu11 -Wextra '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
-                        '-I./Include -I/usr/include -I/usr/include/readline '
-                        '-I/usr/pkg/include -I/usr/include '
-                        '-I/usr/include/readline -I/usr/pkg/include -fPIC',
+                        '-I./Include -I/usr/include -I/usr/pkg/include '
+                        '-I/usr/include -I/usr/pkg/include -fPIC',
  'PY_SUPPORT_TIER': 0,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
@@ -1033,7 +1012,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python311/work.earmv4/Python-3.11.10',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python311/work.earmv7hf/Python-3.11.12',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SHELL': '/bin/sh',
@@ -1077,10 +1056,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python311/work.earmv4/Python-3.11.10 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python311/work.earmv7hf/Python-3.11.12 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python311/work.earmv4/Python-3.11.10 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python311/work.earmv7hf/Python-3.11.12 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -1103,7 +1082,7 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
  'WITH_DYLD': 0,
- 'WITH_EDITLINE': 1,
+ 'WITH_EDITLINE': 0,
  'WITH_FREELISTS': 1,
  'WITH_LIBINTL': 1,
  'WITH_NEXT_FRAMEWORK': 0,
@@ -1111,8 +1090,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/tmp/pkgbuild/lang/python311/work.earmv4/Python-3.11.10',
- 'abs_srcdir': '/tmp/pkgbuild/lang/python311/work.earmv4/Python-3.11.10',
+ 'abs_builddir': '/mnt/earmv7hf/pkgsrc/lang/python311/work.earmv7hf/Python-3.11.12',
+ 'abs_srcdir': '/mnt/earmv7hf/pkgsrc/lang/python311/work.earmv7hf/Python-3.11.12',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
